# n

# Main commands help

Features:
- multiple notebooks
- add notes
- delete notes (single, multiple, range)
- create notebook
- delete notebook


```
Usage:
    n [command]

Available commands:
    add [note]
    ls 
    rm
    rm range
    
    add @[notebook] [note]
    ls @[notebook] 

    add @[notebook]         create notebook
    ls @
    ls @ path               show notebooks w path

    set active [notebook]
    get active

    get notebooks path
    set notebooks path [notebooks path]
```